TimerTrigger

Enum TimerTrigger 

pub enum TimerTrigger {
    Cancel,
    Periodic(u64),
    Relative(u64),
}
Trigger type for events of type TIMER.

See set_timer.

Variants



Cancel

Remove the event’s timer setting.



Periodic(u64)

Trigger the event periodically.

Tuple Fields

0: u64

Duration between event signaling in units of 100ns. If set to zero, the event will be signaled on every timer tick.



Relative(u64)

Trigger the event one time.

Tuple Fields

0: u64

Duration to wait before signaling the event in units of 100ns. If set to zero, the event will be signaled on the next timer tick.