Struct Path
Source pub struct Path();
Available on crate feature alloc only.
A path similar to the Path of the standard library, but based on
CStr16 strings and SEPARATOR as separator.
Returns the underlying string.
Returns a path buf from that type.
Iterator over the components of a path.
Returns the parent directory as PathBuf.
If the path is a top-level component, this returns None.
Returns of the path is empty.
Converts this type into a shared reference of the (usually inferred) input type.
Converts this type into a shared reference of the (usually inferred) input type.
Converts this type into a shared reference of the (usually inferred) input type.
Converts this type into a shared reference of the (usually inferred) input type.
Immutably borrows from an owned value.
Read more
Immutably borrows from an owned value.
Read more
Immutably borrows from an owned value.
Read more
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Converts the given value to a
String.
Read more