DevicePathFromText

Struct DevicePathFromText 

pub struct DevicePathFromText(/* private fields */);
Device Path from Text Protocol.

Protocol for converting a string to a DevicePath or DevicePathNode].

Implementations

Source

impl DevicePathFromText

pub fn convert_text_to_device_node( &self, text_device_node: &CStr16, ) -> Result<PoolDevicePathNode>

Convert a CStr16 to a DevicePathNode.

If a non-device-node character is encountered, the rest of the string is ignored.

Returns an OUT_OF_RESOURCES error if there is insufficient memory for the conversion.

pub fn convert_text_to_device_path( &self, text_device_path: &CStr16, ) -> Result<PoolDevicePath>

Convert a CStr16 to a DevicePath.

If a non-device-node character is encountered, the rest of the string is ignored.

Returns an OUT_OF_RESOURCES error if there is insufficient memory for the conversion.