LoadFile

Struct LoadFile 

pub struct LoadFile(/* private fields */);
Load File Protocol.

Used to obtain files, that are primarily boot options, from arbitrary devices.

UEFI Spec Description

The EFI_LOAD_FILE_PROTOCOL is a simple protocol used to obtain files from arbitrary devices.

When the firmware is attempting to load a file, it first attempts to use the device’s Simple File System protocol to read the file. If the file system protocol is found, the firmware implements the policy of interpreting the File Path value of the file being loaded. If the device does not support the file system protocol, the firmware then attempts to read the file via the EFI_LOAD_FILE_PROTOCOL and the LoadFile() function. In this case the LoadFile() function implements the policy of interpreting the File Path value.

Implementations

Source

impl LoadFile

pub fn load_file<'a>( &mut self, file_path: &DevicePath, boot_policy: BootPolicy, ) -> Result<Box<[u8]>>

Available on crate feature alloc only.

Causes the driver to load a specified file.

Arguments
  • file_path The device specific path of the file to load.
  • boot_policy The BootPolicy to use.
Errors