LoadFile2

Struct LoadFile2 

pub struct LoadFile2(/* private fields */);
Load File2 Protocol.

The Load File2 protocol is used to obtain files from arbitrary devices that are not boot options.

UEFI Spec Description

The EFI_LOAD_FILE2_PROTOCOL is a simple protocol used to obtain files from arbitrary devices that are not boot options. It is used by LoadImage() when its BootOption parameter is FALSE and the FilePath does not have an instance of the EFI_SIMPLE_FILE_SYSTEM_PROTOCOL.

Implementations

Source

impl LoadFile2

pub fn load_file<'a>(&mut self, file_path: &DevicePath) -> Result<Box<[u8]>>

Available on crate feature alloc only.

Causes the driver to load a specified file.

Arguments
  • file_path The device specific path of the file to load.
Errors