pub fn delete_variable(name: &CStr16, vendor: &VariableVendor) -> ResultExpand description
Deletes a UEFI variable.
Errors
Status::INVALID_PARAMETER: invalid name or vendor.Status::WRITE_PROTECTED: variable is read-only.Status::SECURITY_VIOLATION: variable could not be deleted due to an authentication error.Status::NOT_FOUND: attempted to delete a non-existent variable.Status::UNSUPPORTED: this platform does not support variable storage after exiting boot services.