pub fn update_capsule(
capsule_header_array: &[&CapsuleHeader],
capsule_block_descriptors: &[CapsuleBlockDescriptor],
) -> ResultExpand description
Passes capsules to the firmware.
Capsules are most commonly used to update system firmware.
Errors
Status::INVALID_PARAMETER: zero capsules were provided, or the capsules are invalid.Status::DEVICE_ERROR: the capsule update was started but failed to a device error.Status::OUT_OF_RESOURCES: before exiting boot services, indicates the capsule is compatible with the platform but there are insufficient resources to complete the update. After exiting boot services, indicates the capsule is compatible with the platform but can only be processed before exiting boot services.Status::UNSUPPORTED: this platform does not support capsule updates after exiting boot services.