#[repr(C)]
pub struct SystemTable {
pub Hdr: TableHeader,
pub FirmwareVendor: *const u16,
pub FirmwareRevision: u32,
pub ConsoleInHandle: Handle,
pub ConsoleIn: &'static mut TextInput,
pub ConsoleOutHandle: Handle,
pub ConsoleOut: &'static mut TextOutput,
pub ConsoleErrorHandle: Handle,
pub ConsoleError: &'static mut TextOutput,
pub RuntimeServices: &'static mut RuntimeServices,
pub BootServices: &'static mut BootServices,
/* private fields */
}
ConsoleInHandle: HandleConsoleOutHandle: HandleConsoleErrorHandle: Handle
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.