#[repr(C)]
pub struct TextInput {
pub Reset: extern "win64" fn(_: &TextInput, _: bool) -> Status,
pub ReadKeyStroke: extern "win64" fn(_: &TextInput, _: &mut TextInputKey) -> Status,
pub WaitForKey: Event,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.