#[repr(C)]
pub struct TextOutput {
pub Reset: extern "win64" fn(_: &TextOutput, _: bool) -> Status,
pub OutputString: extern "win64" fn(_: &TextOutput, _: *const u16) -> Status,
pub TestString: extern "win64" fn(_: &TextOutput, _: *const u16) -> Status,
pub QueryMode: extern "win64" fn(_: &TextOutput, _: usize, _: &mut usize, _: &mut usize) -> Status,
pub SetMode: extern "win64" fn(_: &TextOutput, _: usize) -> Status,
pub SetAttribute: extern "win64" fn(_: &TextOutput, _: usize) -> Status,
pub ClearScreen: extern "win64" fn(_: &TextOutput) -> Status,
pub SetCursorPosition: extern "win64" fn(_: &TextOutput, _: usize, _: usize) -> Status,
pub EnableCursor: extern "win64" fn(_: &TextOutput, _: bool) -> Status,
pub Mode: &'static TextOutputMode,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.