#[repr(C)]
pub struct TextOutputMode {
pub MaxMode: i32,
pub Mode: i32,
pub Attribute: i32,
pub CursorColumn: i32,
pub CursorRow: i32,
pub CursorVisible: bool,
}
CursorColumn: i32
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.