pub unsafe fn uninstall_protocol_interface(
handle: Handle,
protocol: &Guid,
interface: *const c_void,
) -> Result<()>Expand description
Removes a protocol interface from a device handle.
Safety
The caller is responsible for ensuring that there are no references to a protocol interface that has been removed. Some protocols may not be able to be removed as there is no information available regarding the references. This includes Console I/O, Block I/O, Disk I/o, and handles to device protocols.
The caller is responsible for ensuring that they pass a valid Guid for protocol.
Errors
Status::NOT_FOUND: the interface was not found on the handle.Status::ACCESS_DENIED: the interface is still in use and cannot be uninstalled.