pub struct ComponentName1(/* private fields */);Expand description
Component Name1 Protocol.
Protocol that provides human-readable names for a driver and for each of the controllers that the driver is managing.
This protocol was deprecated in UEFI 2.1 in favor of the new
ComponentName2 protocol. The two protocols are identical except the
encoding of supported languages changed from ISO 639-2 to RFC 4646. The
ComponentName wrapper can be used to automatically select
ComponentName2 if available, and otherwise fall back to
ComponentName1.
The corresponding C type is EFI_COMPONENT_NAME_PROTOCOL.
Implementations
Sourceimpl ComponentName1
impl ComponentName1
Sourcepub const fn supported_languages(
&self,
) -> Result<LanguageIter<'_>, LanguageError>
pub const fn supported_languages( &self, ) -> Result<LanguageIter<'_>, LanguageError>
Get an iterator over supported languages. Each language is identified by a three-letter ASCII string specified in ISO 639-2. For example, English is encoded as โengโ.
Sourcepub fn driver_name(&self, language: &str) -> Result<&CStr16>
pub fn driver_name(&self, language: &str) -> Result<&CStr16>
Get the human-readable name of the driver in the given language.
language must be one of the languages returned by supported_languages.
Sourcepub fn controller_name(
&self,
controller_handle: Handle,
child_handle: Option<Handle>,
language: &str,
) -> Result<&CStr16>
pub fn controller_name( &self, controller_handle: Handle, child_handle: Option<Handle>, language: &str, ) -> Result<&CStr16>
Get the human-readable name of a controller in the given language.
language must be one of the languages returned by supported_languages.