#[repr(C)]
pub struct SystemTable {
pub Hdr: TableHeader,
pub FirmwareVendor: *const u16,
pub FirmwareRevision: u32,
pub ConsoleInHandle: Handle,
pub ConsoleIn: &'static mut TextInput,
pub ConsoleOutHandle: Handle,
pub ConsoleOut: &'static mut TextOutput,
pub ConsoleErrorHandle: Handle,
pub ConsoleError: &'static mut TextOutput,
pub RuntimeServices: &'static mut RuntimeServices,
pub BootServices: &'static mut BootServices,
// some fields omitted
}
ConsoleInHandle: HandleConsoleOutHandle: HandleConsoleErrorHandle: Handle
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.