#[repr(C)]
pub struct TextOutput {
pub Reset: extern "win64" fn(_: &TextOutput, _: bool) -> Status,
pub OutputString: extern "win64" fn(_: &TextOutput, _: *const u16) -> Status,
pub TestString: extern "win64" fn(_: &TextOutput, _: *const u16) -> Status,
pub QueryMode: extern "win64" fn(_: &TextOutput, _: usize, _: &mut usize, _: &mut usize) -> Status,
pub SetMode: extern "win64" fn(_: &TextOutput, _: usize) -> Status,
pub SetAttribute: extern "win64" fn(_: &TextOutput, _: usize) -> Status,
pub ClearScreen: extern "win64" fn(_: &TextOutput) -> Status,
pub SetCursorPosition: extern "win64" fn(_: &TextOutput, _: usize, _: usize) -> Status,
pub EnableCursor: extern "win64" fn(_: &TextOutput, _: bool) -> Status,
pub Mode: &'static TextOutputMode,
}
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.